;; Generated package description from isearch-mb.el  -*- no-byte-compile: t -*-
(define-package "isearch-mb" "0.1.0.20210517.121153" "Control Isearch from the minibuffer" '((emacs "27.1")) :keywords '("matching") :authors '(("Augusto Stoffel" . "arstoffel@gmail.com")) :maintainer '("Augusto Stoffel" . "arstoffel@gmail.com") :url "https://github.com/astoff/isearch-mb")
